==> pygame-2.0.0.tar.gz: pygame-2.0.0/src_c/doc/key_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMEKEY "pygame module to work with the keyboard"
#define DOC_PYGAMEKEYGETFOCUSED "get_focused() -> bool\ntrue if the display is receiving keyboard input from the system"
#define DOC_PYGAMEKEYGETPRESSED "get_pressed() -> bools\nget the state of all keyboard buttons"
#define DOC_PYGAMEKEYGETMODS "get_mods() -> int\ndetermine which modifier keys are being held"
#define DOC_PYGAMEKEYSETMODS "set_mods(int) -> None\ntemporarily set which modifier keys are pressed"
#define DOC_PYGAMEKEYSETREPEAT "set_repeat() -> None\nset_repeat(delay) -> None\nset_repeat(delay, interval) -> None\ncontrol how held keys are repeated"
#define DOC_PYGAMEKEYGETREPEAT "get_repeat() -> (delay, interval)\nsee how held keys are repeated"
#define DOC_PYGAMEKEYNAME "name(key) -> string\nget the name of a key identifier"
#define DOC_PYGAMEKEYKEYCODE "key_code(name=string) -> int\nget the key identifier from a key name"
#define DOC_PYGAMEKEYSTARTTEXTINPUT "start_text_input() -> None\nstart handling IME compositions"
#define DOC_PYGAMEKEYSTOPTEXTINPUT "stop_text_input() -> None\nstop handling IME compositions"
#define DOC_PYGAMEKEYSETTEXTINPUTRECT "set_text_input_rect(Rect) -> None\ncontrols the position of the candidate list"


/* Docs in a comment... slightly easier to read. */

/*

pygame.key
pygame module to work with the keyboard

pygame.key.get_focused
 get_focused() -> bool
true if the display is receiving keyboard input from the system

pygame.key.get_pressed
 get_pressed() -> bools
get the state of all keyboard buttons

pygame.key.get_mods
 get_mods() -> int
determine which modifier keys are being held

pygame.key.set_mods
 set_mods(int) -> None
temporarily set which modifier keys are pressed

pygame.key.set_repeat
 set_repeat() -> None
 set_repeat(delay) -> None
 set_repeat(delay, interval) -> None
control how held keys are repeated

pygame.key.get_repeat
 get_repeat() -> (delay, interval)
see how held keys are repeated

pygame.key.name
 name(key) -> string
get the name of a key identifier

pygame.key.key_code
 key_code(name=string) -> int
get the key identifier from a key name

pygame.key.start_text_input
 start_text_input() -> None
start handling IME compositions

pygame.key.stop_text_input
 stop_text_input() -> None
stop handling IME compositions

pygame.key.set_text_input_rect
 set_text_input_rect(Rect) -> None
controls the position of the candidate list

*/

==> pygame-2.0.3.tar.gz: pygame-2.0.3/src_c/doc/key_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMEKEY "pygame module to work with the keyboard"
#define DOC_PYGAMEKEYGETFOCUSED "get_focused() -> bool\ntrue if the display is receiving keyboard input from the system"
#define DOC_PYGAMEKEYGETPRESSED "get_pressed() -> bools\nget the state of all keyboard buttons"
#define DOC_PYGAMEKEYGETMODS "get_mods() -> int\ndetermine which modifier keys are being held"
#define DOC_PYGAMEKEYSETMODS "set_mods(int) -> None\ntemporarily set which modifier keys are pressed"
#define DOC_PYGAMEKEYSETREPEAT "set_repeat() -> None\nset_repeat(delay) -> None\nset_repeat(delay, interval) -> None\ncontrol how held keys are repeated"
#define DOC_PYGAMEKEYGETREPEAT "get_repeat() -> (delay, interval)\nsee how held keys are repeated"
#define DOC_PYGAMEKEYNAME "name(key) -> string\nget the name of a key identifier"
#define DOC_PYGAMEKEYKEYCODE "key_code(name=string) -> int\nget the key identifier from a key name"
#define DOC_PYGAMEKEYSTARTTEXTINPUT "start_text_input() -> None\nstart handling Unicode text input events"
#define DOC_PYGAMEKEYSTOPTEXTINPUT "stop_text_input() -> None\nstop handling Unicode text input events"
#define DOC_PYGAMEKEYSETTEXTINPUTRECT "set_text_input_rect(Rect) -> None\ncontrols the position of the candidate list"


/* Docs in a comment... slightly easier to read. */

/*

pygame.key
pygame module to work with the keyboard

pygame.key.get_focused
 get_focused() -> bool
true if the display is receiving keyboard input from the system

pygame.key.get_pressed
 get_pressed() -> bools
get the state of all keyboard buttons

pygame.key.get_mods
 get_mods() -> int
determine which modifier keys are being held

pygame.key.set_mods
 set_mods(int) -> None
temporarily set which modifier keys are pressed

pygame.key.set_repeat
 set_repeat() -> None
 set_repeat(delay) -> None
 set_repeat(delay, interval) -> None
control how held keys are repeated

pygame.key.get_repeat
 get_repeat() -> (delay, interval)
see how held keys are repeated

pygame.key.name
 name(key) -> string
get the name of a key identifier

pygame.key.key_code
 key_code(name=string) -> int
get the key identifier from a key name

pygame.key.start_text_input
 start_text_input() -> None
start handling Unicode text input events

pygame.key.stop_text_input
 stop_text_input() -> None
stop handling Unicode text input events

pygame.key.set_text_input_rect
 set_text_input_rect(Rect) -> None
controls the position of the candidate list

*/
